@@ -3,6 +3,7 @@ from django.conf.urls.defaults import patterns, include, url
 from views import GoogleVerificationView
 from views import BingVerificationView
 from views import MajesticVerificationView
+from views import YandexVerificationView
 
 
 urlpatterns = patterns('',
@@ -21,4 +22,9 @@ urlpatterns = patterns('',
         MajesticVerificationView.as_view(),
         name = 'majestic_verify'
     ),
+    url(
+        r'^yandex_(?P<code>[0-9a-f]{16}).txt$',
+        YandexVerificationView.as_view(),
+        name = 'majestic_verify'
+    ),
 )
